# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Single python3 version in Fedora, python3_pkgversion macro not available
%{!?python3_pkgversion:%global python3_pkgversion 3}

# For consistency and completeness
%global python2_pkgversion 2

%global python2ver %(python2 -c "import sys; print sys.version[:3]" 2>/dev/null || echo 0.0)
%global python3ver %(python3 -c "import sys; sys.stdout.write('{0.major}.{0.minor}'.format(sys.version_info))" 2>/dev/null || echo 0.0)

# python3-pytest does not provide /usr/bin/pytest-3 prior to F-26
%global pytest3_binary_available (0%{?fedora} > 25 || 0%{?rhel} > 7)

# TODO: Use python-scrypt for speed improvements

Name:		python-passlib
Version:	1.7.4
Release:	17.%{__distinit}%{__distvers}
Summary:	Comprehensive password hashing framework supporting over 20 schemes
# license breakdown is described in LICENSE file
License:	BSD-3-Clause AND Beerware AND UnixCrypt AND ISC
URL:		https://foss.heptapod.net/python-libs/passlib/-/wikis/home
Source0:	https://pypi.python.org/packages/source/p/passlib/passlib-%{version}.tar.gz
Patch10:	passlib-1.7.0-test.patch
BuildArch:	noarch
BuildRequires:	coreutils
# docs generation requires python-cloud-sptheme, which isn't packaged yet
# so we won't generate the docs yet
#BuildRequires: python2-sphinx >= 1.0
#BuildRequires: python2-cloud-sptheme

%description
Passlib is a password hashing library for Python 2 and 3, which provides
cross-platform implementations of over 20 password hashing algorithms,
as well as a framework for managing existing password hashes. It's
designed to be useful for a wide range of tasks, from verifying a hash
found in /etc/shadow, to providing full-strength password hashing for
multi-user application.

%package -n python%{python2_pkgversion}-passlib
Summary:	Comprehensive password hashing framework supporting over 20 schemes
Provides:	python-passlib = %{version}-%{release}
Obsoletes:	python-passlib < %{version}-%{release}
BuildRequires:	python%{python2_pkgversion}-devel >= 2.6
%if 0%{?fedora} && 0%{?fedora} <= 22
BuildRequires:	python-setuptools
%else
BuildRequires:	python%{python2_pkgversion}-setuptools
%endif
%if 0%{?fedora} && 0%{?fedora} <= 21
BuildRequires:	python-nose >= 1.1
%else
BuildRequires:	python%{python2_pkgversion}-nose >= 1.1
%endif
%if 0%{?fedora} < 23 && 0%{?rhel} < 7
BuildRequires:	python%{python2_pkgversion}-py-bcrypt
Requires:	python%{python2_pkgversion}-py-bcrypt
%else
BuildRequires:	python%{python2_pkgversion}-bcrypt
Requires:	python%{python2_pkgversion}-bcrypt
%endif

%description -n python%{python2_pkgversion}-passlib
Passlib is a password hashing library for Python 2 and 3, which provides
cross-platform implementations of over 20 password hashing algorithms,
as well as a framework for managing existing password hashes. It's
designed to be useful for a wide range of tasks, from verifying a hash
found in /etc/shadow, to providing full-strength password hashing for
multi-user application.

# https://fedoraproject.org/wiki/Changes/PythonExtras
%{?python_extras_subpkg:%python_extras_subpkg -n python3-passlib -i %{python3_sitelib}/*.egg-info argon2 bcrypt totp}

%package -n python%{python3_pkgversion}-passlib
Summary:	Comprehensive password hashing framework supporting over 20 schemes
BuildRequires:	python%{python3_pkgversion}-devel >= 3.3
BuildRequires:	python%{python3_pkgversion}-setuptools
%if %{pytest3_binary_available}
BuildRequires:	python%{python3_pkgversion}-pytest
%else
BuildRequires:	python%{python3_pkgversion}-nose >= 1.1
%endif
%if 0%{?fedora} < 23 && 0%{?rhel} < 7
BuildRequires:	python%{python3_pkgversion}-py-bcrypt
Requires:	python%{python3_pkgversion}-py-bcrypt
%else
BuildRequires:	python%{python3_pkgversion}-bcrypt
Requires:	python%{python3_pkgversion}-bcrypt
%endif
%if 0%{?python_extras_subpkg:1}
BuildRequires:	python3-argon2-cffi >= 18.2
BuildRequires:	python3-cryptography
%endif

%description -n python%{python3_pkgversion}-passlib
Passlib is a password hashing library for Python 2 and 3, which provides
cross-platform implementations of over 20 password hashing algorithms,
as well as a framework for managing existing password hashes. It's
designed to be useful for a wide range of tasks, from verifying a hash
found in /etc/shadow, to providing full-strength password hashing for
multi-user application.

%prep
%setup -q -n passlib-%{version}

# Remove old versions of doc images
rm docs/_static/bb-logo.{png,svg}.orig

# Fix test suite for python3 < 3.4
%patch -P 10

# Remove upstream egg-info, we'll rebuild it ourselves
rm -rf passlib.egg-info

%build
%{__python2} setup.py build
%{__python3} setup.py build

%install
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}
%{__python3} setup.py install -O1 --skip-build --root %{buildroot}

%check
%{__python2} setup.py test
%if %{pytest3_binary_available}
PYTHONDONTWRITEBYTECODE=1 pytest-3
%else
%{__python3} setup.py test
%endif

%files -n python%{python2_pkgversion}-passlib
%license LICENSE
%doc docs/* README
%{python2_sitelib}/passlib/
%{python2_sitelib}/passlib-%{version}-py%{python2ver}.egg-info/

%files -n python%{python3_pkgversion}-passlib
%license LICENSE
%doc docs/* README
%{python3_sitelib}/passlib/
%{python3_sitelib}/passlib-%{version}-py%{python3ver}.egg-info/

%changelog
* Tue Feb 27 2024 Paul Howarth <paul@city-fan.org> - 1.7.4-17
- Add buildrequires for extra sub-packages

* Tue Jan 30 2024 Paul Howarth <paul@city-fan.org> - 1.7.4-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jul 21 2023 Paul Howarth <paul@city-fan.org> - 1.7.4-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Wed Jul  5 2023 Paul Howarth <paul@city-fan.org> - 1.7.4-12
- Rebuilt for Python 3.12

* Sun Jun  4 2023 Paul Howarth <paul@city-fan.org> - 1.7.4-11
- Update license field with SPDX approved UnixCrypt identifier
- Avoid use of deprecated patch syntax

* Tue Jan 24 2023 Paul Howarth <paul@city-fan.org> - 1.7.4-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Tue Oct 25 2022 Paul Howarth <paul@city-fan.org> - 1.7.4-9
- Run Python 3 tests with pytest instead of deprecated nose
- Switch license field to SPDX identifiers

* Mon Jul 25 2022 Paul Howarth <paul@city-fan.org> - 1.7.4-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 20 2022 Paul Howarth <paul@city-fan.org> - 1.7.4-7
- Rebuilt for Python 3.11

* Wed Jan 26 2022 Paul Howarth <paul@city-fan.org> - 1.7.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Jul 28 2021 Paul Howarth <paul@city-fan.org> - 1.7.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild
- Fix dist tags for Alma and Rocky Linux

* Tue Jun  8 2021 Paul Howarth <paul@city-fan.org> - 1.7.4-4
- Rebuilt for Python 3.10

* Tue Jun  8 2021 Paul Howarth <paul@city-fan.org> - 1.7.4-3
- Add extras metapackages for argon2, bcrypt, totp

* Fri Oct  9 2020 Paul Howarth <paul@city-fan.org> - 1.7.4-1
- Update to 1.7.4 (see history/1.7.rst for details)
- Upstream moved from bitbucket.org to foss.heptapod.net

* Sun May 31 2020 Paul Howarth <paul@city-fan.org> - 1.7.2-2
- Add fix for Python 3.9

* Mon Nov 25 2019 Paul Howarth <paul@city-fan.org> - 1.7.2-1
- Update to 1.7.2 (see history/1.7.rst for details)
- Drop patches that are no longer needed
- Use python-bcrypt rather than python-py-bcrypt from F-23 onwards
  (python-py-bcrypt is deprecated and will not be supported in 1.8.x)

* Mon Aug 26 2019 Paul Howarth <paul@city-fan.org> - 1.7.1-5
- Add fixes for Python 3.8 support

* Tue Jul 10 2018 Paul Howarth <paul@city-fan.org> - 1.7.1-3
- Rebuild for Python 3.7

* Fri Mar 16 2018 Paul Howarth <paul@city-fan.org> - 1.7.1-2
- crypt() via libxcrypt has bsdi_crypt and sha1_crypt support
- Update Python 2 dependency declarations to new packaging standards
- Upstream home is on BitBucket
- Add support for Python 3.4 build for EL-7
- Remove explicit %%clean section

* Tue Jan 31 2017 Paul Howarth <paul@city-fan.org> - 1.7.1-1
- Update to 1.7.1 (see history/1.7.rst for details)
- Drop patches that are no longer needed

* Sun Dec 25 2016 Paul Howarth <paul@city-fan.org> - 1.7.0-2
- Rebuild for Python 3.6 in Rawhide

* Wed Nov 23 2016 Paul Howarth <paul@city-fan.org> - 1.7.0-1
- Update to 1.7.0 (see history/1.7.rst for details)
- Add patch to fix version string mangling
- Build python3 package unconditionally
- Add patch to fix test suite for python3 < 3.4

* Tue Oct 18 2016 Paul Howarth <paul@city-fan.org> - 1.6.5-4
- Generate python2 and python3 packages

* Wed Aug  5 2015 Paul Howarth <paul@city-fan.org> - 1.6.5-1
- Update to 1.6.5 (test suite fixes for python 2.5)
- Drop upstreamed fixes for python 2.5 support

* Thu Jul 30 2015 Paul Howarth <paul@city-fan.org> - 1.6.4-3
- Add workaround for bug in python 2.5.0 parser breaking
  from __future__ import with_statement, absolute_import

* Wed Jul 29 2015 Paul Howarth <paul@city-fan.org> - 1.6.4-2
- Use upstream fix for python 2.5 compatibility
  (https://bitbucket.org/ecollins/passlib/issues/58/)

* Mon Jul 27 2015 Paul Howarth <paul@city-fan.org> - 1.6.4-1
- Update to 1.6.4 (see CHANGES for details)
- Upstream moved from Google Code to Python Hosted
- Add fixes for a couple of test suite issues
- Use %%license where possible

* Wed Jan  1 2014 Paul Howarth <paul@city-fan.org> - 1.6.2-1
- Update to 1.6.2
  - Minor changes and compatibility fixes
    - Re-tuned the ~passlib.ifc.PasswordHash.default_rounds values for
      all of the hashes
    - Added the new bcrypt_sha256 hash, which wraps BCrypt using SHA256 in
      order to work around BCrypt's password size limitations (Issue 43)
    - passlib.hash.bcrypt: added support for the bcrypt library as one of the
      possible bcrypt backends that will be used if available (Issue 49)
    - passlib.ext.django: passlib's Django extension (and its related hashes
      and unittests) have been updated to handle some minor API changes in
      Django 1.5-1.6; they should now be compatible with Django 1.2 and up
      (Issue 50)
- BR: backend library py-bcrypt, required by test suite

* Sun Mar 17 2013 Paul Howarth <paul@city-fan.org> - 1.6.1-1
- Import from Fedora
- Update to 1.6.1

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Oct 17 2011 Matt Domsch <Matt_Domsch@dell.com> - 1.5.3-1
- Initial release for Fedora
